﻿/// <reference path="../../../Resources/TypeDefinitions/jquery/jquery.d.ts"/>
/// <reference path="../../../Resources/TypeDefinitions/knockout/knockout.d.ts"/>
/// <reference path="../../../Resources/TypeDefinitions/inedojq/inedojq_frameddialog.d.ts"/>
/// <reference path="../../../rubbish.ts"/>
var EventLogPage;
(function (EventLogPage) {
    var EventListViewModel = (function () {
        function EventListViewModel(inputData) {
            var _this = this;
            this.inputData = inputData;
            this.events = ko.observable();
            this.maxCount = ko.observable(25);
            this.loading = ko.observable(false);
            this.userFilter = ko.observable('');
            this.feedFilter = ko.observable(null);
            this.users = [null].concat(inputData.users);
            this.feeds = [null].concat(inputData.feeds);
            this.update();

            var subscribe = function (handler) {
                var observables = [];
                for (var _i = 0; _i < (arguments.length - 1); _i++) {
                    observables[_i] = arguments[_i + 1];
                }
                for (var i = 0; i < observables.length; i++)
                    observables[i].subscribe(handler);
            };

            subscribe(function () {
                return _this.update();
            }, this.maxCount, this.userFilter, this.feedFilter);
        }
        EventListViewModel.prototype.update = function () {
            var _this = this;
            if (!this.loading()) {
                this.loading(true);
                $.ajax({
                    type: 'POST',
                    url: this.inputData.updateUrl,
                    data: { maxCount: this.maxCount(), userName: this.userFilter() || '', feedId: this.feedFilter() || 0 },
                    success: function (results) {
                        _this.events(results);
                    },
                    complete: function () {
                        _this.loading(false);
                    }
                });
            }
        };

        EventListViewModel.prototype.getUserName = function (item) {
            return item || '(any)';
        };

        EventListViewModel.prototype.getFeedName = function (item) {
            return item ? item.name : '(any)';
        };

        EventListViewModel.prototype.getFeedValue = function (item) {
            return item ? item.id : null;
        };

        EventListViewModel.prototype.eventClick = function (id) {
            $.inedojq_frameddialog(this.inputData.detailsUrl + '?eventOccurrenceId=' + id);
        };
        return EventListViewModel;
    })();

    function Init(o) {
        ko.applyBindings(new EventListViewModel(o));
    }
    EventLogPage.Init = Init;
})(EventLogPage || (EventLogPage = {}));
